@@ -195,8 +195,10 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 	#------------------------------------------------------------
 	def _on_new_button_pressed(self, event):
 		if not self.new_callback():
+			self._LCTRL_items.SetFocus()
 			return
 		if self.refresh_callback is None:
+			self._LCTRL_items.SetFocus()
 			return
 		wx.BeginBusyCursor()
 		try:
@@ -204,13 +206,16 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 		finally:
 			wx.EndBusyCursor()
 		self._LCTRL_items.set_column_widths()
+		self._LCTRL_items.SetFocus()
 	#------------------------------------------------------------
 	def _on_edit_button_pressed(self, event):
 		# if the edit button *can* be pressed there are *supposed*
 		# to be both an item selected and an editor configured
 		if not self.edit_callback(self._LCTRL_items.get_selected_item_data(only_one=True)):
+			self._LCTRL_items.SetFocus()
 			return
 		if self.refresh_callback is None:
+			self._LCTRL_items.SetFocus()
 			return
 		wx.BeginBusyCursor()
 		try:
@@ -218,16 +223,20 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 		finally:
 			wx.EndBusyCursor()
 		self._LCTRL_items.set_column_widths()
+		self._LCTRL_items.SetFocus()
 	#------------------------------------------------------------
 	def _on_delete_button_pressed(self, event):
 		# if the delete button *can* be pressed there are *supposed*
 		# to be both an item selected and a deletor configured
 		item_data = self._LCTRL_items.get_selected_item_data(only_one=True)
 		if item_data is None:
+			self._LCTRL_items.SetFocus()
 			return
 		if not self.delete_callback(item_data):
+			self._LCTRL_items.SetFocus()
 			return
 		if self.refresh_callback is None:
+			self._LCTRL_items.SetFocus()
 			return
 		wx.BeginBusyCursor()
 		try:
@@ -235,12 +244,15 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 		finally:
 			wx.EndBusyCursor()
 		self._LCTRL_items.set_column_widths()
+		self._LCTRL_items.SetFocus()
 	#------------------------------------------------------------
 	def _on_left_extra_button_pressed(self, event):
 		item_data = self._LCTRL_items.get_selected_item_data(only_one=True)
 		if not self.__left_extra_button_callback(item_data):
+			self._LCTRL_items.SetFocus()
 			return
 		if self.refresh_callback is None:
+			self._LCTRL_items.SetFocus()
 			return
 		wx.BeginBusyCursor()
 		try:
@@ -248,12 +260,15 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 		finally:
 			wx.EndBusyCursor()
 		self._LCTRL_items.set_column_widths()
+		self._LCTRL_items.SetFocus()
 	#------------------------------------------------------------
 	def _on_middle_extra_button_pressed(self, event):
 		item_data = self._LCTRL_items.get_selected_item_data(only_one=True)
 		if not self.__middle_extra_button_callback(item_data):
+			self._LCTRL_items.SetFocus()
 			return
 		if self.refresh_callback is None:
+			self._LCTRL_items.SetFocus()
 			return
 		wx.BeginBusyCursor()
 		try:
@@ -261,12 +276,15 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 		finally:
 			wx.EndBusyCursor()
 		self._LCTRL_items.set_column_widths()
+		self._LCTRL_items.SetFocus()
 	#------------------------------------------------------------
 	def _on_right_extra_button_pressed(self, event):
 		item_data = self._LCTRL_items.get_selected_item_data(only_one=True)
 		if not self.__right_extra_button_callback(item_data):
+			self._LCTRL_items.SetFocus()
 			return
 		if self.refresh_callback is None:
+			self._LCTRL_items.SetFocus()
 			return
 		wx.BeginBusyCursor()
 		try:
@@ -274,6 +292,7 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 		finally:
 			wx.EndBusyCursor()
 		self._LCTRL_items.set_column_widths()
+		self._LCTRL_items.SetFocus()
 	#------------------------------------------------------------
 	# properties
 	#------------------------------------------------------------
@@ -430,8 +449,8 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 		self._LCTRL_items.item_tooltip_callback = callback
 
 	list_tooltip_callback = property(lambda x:x, _set_list_tooltip_callback)
-	#def _get_tooltip(self, item):		# inside class
-	#def _get_tooltip(item):			# outside class
+	#def _get_tooltip(self, item):		# inside a class
+	#def _get_tooltip(item):			# outside a class
 	#------------------------------------------------------------
 	def _set_message(self, message):
 		if message is None:
@@ -466,6 +485,8 @@ class cGenericListManagerPnl(wxgGenericListManagerPnl.wxgGenericListManagerPnl):
 		self.edit_callback = None				# called when EDIT button pressed, data of topmost selected item passed in
 		self.delete_callback = None				# called when DELETE button pressed, data of topmost selected item passed in
 		self.refresh_callback = None			# called when new/edit/delete callbacks return True (IOW were not cancelled)
+
+		self.__select_callback = None			# called when an item is selected, data of topmost selected item passed in
 	#------------------------------------------------------------
 	# external API
 	#------------------------------------------------------------
@@ -498,11 +519,16 @@ class cGenericListManagerPnl(wxgGenericListManagerPnl.wxgGenericListManagerPnl):
 			self._BTN_edit.Enable(True)
 		if self.delete_callback is not None:
 			self._BTN_remove.Enable(True)
+		if self.__select_callback is not None:
+			item = self._LCTRL_items.get_selected_item_data(only_one=True)
+			self.__select_callback(item)
 	#------------------------------------------------------------
 	def _on_list_item_deselected(self, event):
 		if self._LCTRL_items.get_selected_items(only_one=True) == -1:
 			self._BTN_edit.Enable(False)
 			self._BTN_remove.Enable(False)
+			if self.__select_callback is not None:
+				self.__select_callback(None)
 	#------------------------------------------------------------
 	def _on_add_button_pressed(self, event):
 		if not self.new_callback():
@@ -515,6 +541,11 @@ class cGenericListManagerPnl(wxgGenericListManagerPnl.wxgGenericListManagerPnl):
 		finally:
 			wx.EndBusyCursor()
 	#------------------------------------------------------------
+	def _on_list_item_activated(self, event):
+		if self.edit_callback is None:
+			return
+		self._on_edit_button_pressed(event)
+	#------------------------------------------------------------
 	def _on_edit_button_pressed(self, event):
 		item = self._LCTRL_items.get_selected_item_data(only_one=True)
 		if item is None:
@@ -549,10 +580,38 @@ class cGenericListManagerPnl(wxgGenericListManagerPnl.wxgGenericListManagerPnl):
 		return self.__new_callback
 
 	def _set_new_callback(self, callback):
+		if callback is not None:
+			if not callable(callback):
+				raise ValueError('<new> callback is not a callable: %s' % callback)
 		self.__new_callback = callback
 		self._BTN_add.Enable(callback is not None)
 
 	new_callback = property(_get_new_callback, _set_new_callback)
+	#------------------------------------------------------------
+	def _get_select_callback(self):
+		return self.__select_callback
+
+	def _set_select_callback(self, callback):
+		if callback is not None:
+			if not callable(callback):
+				raise ValueError('<select> callback is not a callable: %s' % callback)
+		self.__select_callback = callback
+
+	select_callback = property(_get_select_callback, _set_select_callback)
+	#------------------------------------------------------------
+	def _get_message(self):
+		return self._LBL_message.GetLabel()
+
+	def _set_message(self, msg):
+		if msg is None:
+			self._LBL_message.Hide()
+			self._LBL_message.SetLabel(u'')
+		else:
+			self._LBL_message.SetLabel(msg)
+			self._LBL_message.Show()
+		self.Layout()
+
+	message = property(_get_message, _set_message)
 #================================================================
 from Gnumed.wxGladeWidgets import wxgItemPickerDlg
 
@@ -785,9 +844,23 @@ A discontinuous selection may depend on your holding down a platform-dependent m
 	#------------------------------------------------------------
 	def set_selections(self, selections=None):
 		self.Select(0, on = 0)
+		if selections is None:
+			return
 		for idx in selections:
 			self.Select(idx = idx, on = 1)
 			#self.SetItemState(idx, wx.LIST_STATE_SELECTED, wx.LIST_STATE_SELECTED)
+
+	def __get_selections(self):
+		if self.__is_single_selection:
+			return [self.GetFirstSelected()]
+		selections = []
+		idx = self.GetFirstSelected()
+		while idx != -1:
+			selections.append(idx)
+			idx = self.GetNextSelected(idx)
+		return selections
+
+	selections = property(__get_selections, set_selections)
 	#------------------------------------------------------------
 	# getters
 	#------------------------------------------------------------
